0.6
---

* Added support for h5pyd objects in the notebook interface:
  https://github.com/European-XFEL/h5glance/pull/11
* Improved expand/collapse icons in the notebook interface:
  https://github.com/European-XFEL/h5glance/pull/12
* Don't crash the terminal interface when attributes are unreadable:
  https://github.com/European-XFEL/h5glance/pull/13
